(*
 *
 *              A Mail Filtering and Control Utility   "MailUtl"
 *                     Copyright (C) 2002-2005  Fumio KAWAMATA
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.
 *
 *)
unit MailUtl2_Settings;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, ExtCtrls;

type
  TFormSettings = class(TForm)
    LabeledEditHostname: TLabeledEdit;
    LabeledEditPort: TLabeledEdit;
    LabeledEditUserName: TLabeledEdit;
    LabeledEditLogDir: TLabeledEdit;
    LabeledEditRuleFileName: TLabeledEdit;
    LabeledEditMaxLines: TLabeledEdit;
    BitBtnOK: TBitBtn;
    BitBtnCancel: TBitBtn;
    LabeledEditPassword: TLabeledEdit;
    BitBtnLogDir: TBitBtn;
    BitBtnRuleFileName: TBitBtn;
    OpenDialog: TOpenDialog;
    CheckBoxUseMailUtlRules: TCheckBox;
    procedure BitBtnCancelClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure BitBtnOKClick(Sender: TObject);
    procedure BitBtnLogDirClick(Sender: TObject);
    procedure BitBtnRuleFileNameClick(Sender: TObject);
  private
  public
  end;

var
  FormSettings: TFormSettings;



implementation

{$R *.dfm}
uses
  FileCtrl, MailUtl2_DM, MailUtl2_Global, FormStatus;

var
  Msg: TMessage = (Msg: CM_PARENTFONTCHANGED);
  (* TMessage requires Messages unit. *)
  (* CM_PARENTFONTCHANGED requires Controls unit. *)


procedure TFormSettings.BitBtnCancelClick(Sender: TObject);
begin
  try
    StrToInt(LabeledEditMaxLines.Text);
  except
    MessageDlg('Max lines must be over 0', mtWarning, [mbOK], 0);
    Exit;
  end;
  Close;
end;

procedure TFormSettings.FormDestroy(Sender: TObject);
begin
  FormStatus.WriteFormStatusToIniFile(FormSettings, MailUtl2_Global.IniFileFullPath);
end;

procedure TFormSettings.FormCreate(Sender: TObject);
begin
  FormStatus.ReadFormStatusFromIniFile(FormSettings, MailUtl2_Global.IniFileFullPath);
  LabeledEditHostName.Text:=POP3_Host;
  LabeledEditPort.Text:=IntToStr(POP3_Port);
  LabeledEditUserName.Text:=POP3_UserName;
  LabeledEditPassword.Text:=POP3_Password;
  LabeledEditLogDir.Text:=LogDir;
  LabeledEditRuleFileName.Text:=RuleFileName;
  LabeledEditMaxLines.Text:=IntToStr(MaxLines);
  CheckBoxUseMailUtlRules.Checked:=UseMailUtlRules;
end;



procedure TFormSettings.BitBtnOKClick(Sender: TObject);
begin
  if DirectoryExists(LabeledEditLogDir.Text)=False then
  begin
    MessageDlg('Log directory is not existed.', mtWarning, [mbOK], 0);
    Exit;
  end;
  try
    StrToInt(LabeledEditMaxLines.Text);
  except
    MessageDlg('Max lines must be over 0', mtWarning, [mbOK], 0);
    Exit;
  end;
  POP3_Host:=LabeledEditHostName.Text;
  POP3_Port:=StrToInt(LabeledEditPort.Text);
  POP3_UserName:=LabeledEditUserName.Text;
  POP3_Password:=LabeledEditPassword.Text;
  LogDir:=LabeledEditLogDir.Text;
  RuleFileName:=LabeledEditRuleFileName.Text;
  MaxLines:=StrToInt(LabeledEditMaxLines.Text);
  UseMailUtlRules:=CheckBoxUseMailUtlRules.Checked;
  Close;
end;



procedure TFormSettings.BitBtnLogDirClick(Sender: TObject);
var
  Dir: String;
begin
  Dir:= LabeledEditLogDir.Text;
  try
    if SelectDirectory(Dir, [sdAllowCreate, sdPerformCreate, sdPrompt], 0)=True then
    begin
      LabeledEditLogDir.Text:= Dir;
    end;
  except
    if MessageDlg('The directory in the textbox is not existed.  Do you reset it as a default directory?', mtConfirmation, [mbOK, mbNo], 0)=mrOK then
    begin
      LabeledEditLogDir.Text:=SysUtils.GetEnvironmentVariable('TEMP');
    end;
  end;
end;



procedure TFormSettings.BitBtnRuleFileNameClick(Sender: TObject);
begin
  OpenDialog.DefaultExt:='TXT';
  OpenDialog.InitialDir:=ExtractFileDir(ParamStr(0));
  OpenDialog.Filter := 'Text files (*.txt)|*.TXT|All files (*.*)|*.*';
  OpenDialog.Options:=[ofHideReadOnly, ofPathMustExist, ofFileMustExist, ofNoNetworkButton];
  if OpenDialog.Execute=True then
  begin
    LabeledEditRuleFileName.Text:=OpenDialog.FileName;
  end;
end;


end.
